@@ -1,16 +1,16 @@
 #! /usr/bin/env/python
 # -*- coding: utf-8 -*-
-# cython: language_level=3
+# cython: language_level=3, always_allow_keywords=True
 
-## Copyright 1999-2013 by LivingLogic AG, Bayreuth/Germany
-## Copyright 1999-2013 by Walter Dörwald
+## Copyright 1999-2017 by LivingLogic AG, Bayreuth/Germany
+## Copyright 1999-2017 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
 ## See ll/xist/__init__.py for the license
 
 
-import sys, unittest, io
+import sys, io
 
 from xml.parsers import expat
 
@@ -348,13 +348,13 @@ def test_attributekeysvaluesitems():
 			class attr_(xsc.TextAttr):
 				xmlname = "attr"
 
-	yield check, Test1(), Test1.Attrs.attr_, "42"
-	yield check, Test1(attr_=17), Test1.Attrs.attr_, "17"
-	yield check, Test1(attr_=None), Test1.Attrs.attr_, None
+	check(Test1(), Test1.Attrs.attr_, "42")
+	check(Test1(attr_=17), Test1.Attrs.attr_, "17")
+	check(Test1(attr_=None), Test1.Attrs.attr_, None)
 
-	yield check, Test2(), Test2.Attrs.attr_, None
-	yield check, Test2(attr_=17), Test2.Attrs.attr_, "17"
-	yield check, Test2(attr_=None), Test2.Attrs.attr_, None
+	check(Test2(), Test2.Attrs.attr_, None)
+	check(Test2(attr_=17), Test2.Attrs.attr_, "17")
+	check(Test2(attr_=None), Test2.Attrs.attr_, None)
 
 
 def test_attributeswithoutnames():
@@ -944,3 +944,8 @@ def test_plainprocinst_mapped():
 
 	assert node.__class__ is xsc.ProcInst
 	assert node.xmlname == "foo"
+
+
+def test_clone_plain_attributes():
+	node = html.p({"data-id": 42})
+	assert node.clone().string() == '<p data-id="42"></p>'
