@@ -1,12 +1,13 @@
 #! /usr/bin/env/python
 # -*- coding: utf-8 -*-
+# cython: language_level=3, always_allow_keywords=True
 
-## Copyright 1999-2011 by LivingLogic AG, Bayreuth/Germany
-## Copyright 1999-2011 by Walter Dörwald
+## Copyright 1999-2017 by LivingLogic AG, Bayreuth/Germany
+## Copyright 1999-2017 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
-## See ll/__init__.py for the license
+## See ll/xist/__init__.py for the license
 
 
 from ll.xist import xsc, parse
@@ -54,10 +55,10 @@ def test_publishprocinst():
 
 
 def test_publishboolattr():
-	node = html.td(u"?", nowrap=None)
+	node = html.td("?", nowrap=None)
 	assert node.bytes(xhtml=0) == b"""<td>?</td>"""
 
-	node = html.td(u"?", nowrap=True)
+	node = html.td("?", nowrap=True)
 	assert node.bytes(xhtml=0) == b"""<td nowrap>?</td>"""
 	assert node.bytes(xhtml=1) == b"""<td nowrap="nowrap">?</td>"""
 	assert node.bytes(xhtml=2) == b"""<td nowrap="nowrap">?</td>"""
@@ -68,14 +69,14 @@ def test_publishboolattr():
 				xmlname = "baz"
 
 	# Check that the XML name is used as the value
-	assert foo(u"?", bar=True).bytes(xhtml=2) == b"""<foo baz="baz">?</foo>"""
+	assert foo("?", bar=True).bytes(xhtml=2) == b"""<foo baz="baz">?</foo>"""
 
 
 def test_publishurlattr():
 	node = html.link(href=None)
 	assert node.bytes(xhtml=1) == b"""<link />"""
 
-	node = html.link(href=u"root:gurk.html")
+	node = html.link(href="root:gurk.html")
 	assert node.bytes(xhtml=1) == b"""<link href="root:gurk.html" />"""
 	assert node.bytes(xhtml=1, base="root:gurk.html") == b"""<link href="" />"""
 	assert node.bytes(xhtml=1, base="root:hurz.html") == b"""<link href="gurk.html" />"""
@@ -85,34 +86,34 @@ def test_publishstyleattr():
 	node = html.div(style=None)
 	assert node.bytes(xhtml=1) == b"""<div></div>"""
 
-	node = html.div(style=u"background-image: url(root:gurk.html)")
+	node = html.div(style="background-image: url(root:gurk.html)")
 	assert node.bytes(xhtml=1) == b"""<div style="background-image: url(root:gurk.html)"></div>"""
 	assert node.bytes(xhtml=1, base="root:gurk.html") == b"""<div style="background-image: url()"></div>"""
 	assert node.bytes(xhtml=1, base="root:hurz.html") == b"""<div style="background-image: url(gurk.html)"></div>"""
 
 
 def test_publishxmlattr():
-	node = html.html(xml.Attrs(space=u"preserve"))
+	node = html.html(xml.Attrs(space="preserve"))
 	assert node.bytes(prefixdefault=False) == b"""<html xml:space="preserve"></html>"""
 	assert node.bytes(prefixdefault=True) == b"""<ns:html xmlns:ns="http://www.w3.org/1999/xhtml" xml:space="preserve"></ns:html>"""
 	assert node.bytes(prefixdefault=None) == b"""<html xmlns="http://www.w3.org/1999/xhtml" xml:space="preserve"></html>"""
-	assert node.bytes(prefixes={html: u"h"}) == b"""<h:html xmlns:h="http://www.w3.org/1999/xhtml" xml:space="preserve"></h:html>"""
+	assert node.bytes(prefixes={html: "h"}) == b"""<h:html xmlns:h="http://www.w3.org/1999/xhtml" xml:space="preserve"></h:html>"""
 	# Prefix for XML namespace can't be overwritten
-	assert node.bytes(prefixes={html: u"h", xml: u"spam"}) == b"""<h:html xmlns:h="http://www.w3.org/1999/xhtml" xml:space="preserve"></h:html>"""
+	assert node.bytes(prefixes={html: "h", xml: "spam"}) == b"""<h:html xmlns:h="http://www.w3.org/1999/xhtml" xml:space="preserve"></h:html>"""
 
 
 def test_publishglobalattr():
 	# FIXME: Some of those tests depend on dict iteration order
-	node = html.html(xlink.Attrs(title=u"the foo bar"))
+	node = html.html(xlink.Attrs(title="the foo bar"))
 	assert node.bytes(prefixdefault=False) == b"""<html xmlns:ns="http://www.w3.org/1999/xlink" ns:title="the foo bar"></html>"""
 	assert node.bytes(prefixdefault=None) == b"""<html xmlns="http://www.w3.org/1999/xhtml" xmlns:ns="http://www.w3.org/1999/xlink" ns:title="the foo bar"></html>"""
 	assert node.bytes(prefixdefault=True) == b"""<ns:html xmlns:ns="http://www.w3.org/1999/xhtml" xmlns:ns2="http://www.w3.org/1999/xlink" ns2:title="the foo bar"></ns:html>"""
-	assert node.bytes(prefixdefault=u"h") == b"""<h:html xmlns:h="http://www.w3.org/1999/xhtml" xmlns:ns="http://www.w3.org/1999/xlink" ns:title="the foo bar"></h:html>"""
-	assert node.bytes(prefixes={html: u"h", xlink: u"xl"}) == b"""<h:html xmlns:h="http://www.w3.org/1999/xhtml" xmlns:xl="http://www.w3.org/1999/xlink" xl:title="the foo bar"></h:html>"""
+	assert node.bytes(prefixdefault="h") == b"""<h:html xmlns:h="http://www.w3.org/1999/xhtml" xmlns:ns="http://www.w3.org/1999/xlink" ns:title="the foo bar"></h:html>"""
+	assert node.bytes(prefixes={html: "h", xlink: "xl"}) == b"""<h:html xmlns:h="http://www.w3.org/1999/xhtml" xmlns:xl="http://www.w3.org/1999/xlink" xl:title="the foo bar"></h:html>"""
 
 
 def test_publishspecialsurl():
-	node = specials.url(u"root:gurk.html")
+	node = specials.url("root:gurk.html")
 	assert node.bytes() == b"""root:gurk.html"""
 	assert node.bytes(base="root:gurk.html") == b""""""
 	assert node.bytes(base="root:hurz.html") == b"""gurk.html"""
@@ -126,7 +127,7 @@ def test_publishempty():
 
 
 def test_publishescaped():
-	s = u"""\x04<&'"\xff>"""
+	s = """\x04<&'"\xff>"""
 	node = xsc.Text(s)
 	assert node.bytes(encoding="ascii") == b"""&#4;&lt;&amp;'"&#255;&gt;"""
 	node = html.span(class_=s)
@@ -137,10 +138,10 @@ def test_encoding():
 	def check(encoding):
 		node = xsc.Frag(
 			html.div(
-				php.php(u"echo $foo"),
+				php.php("echo $foo"),
 				abbr.html(),
-				html.div(u"gurk", class_=u"hurz"),
-				u"\u3042",
+				html.div("gurk", class_="hurz"),
+				"\u3042",
 			)
 		)
 		s = node.bytes(encoding=encoding)
@@ -148,7 +149,7 @@ def test_encoding():
 		assert node == node2
 
 	for encoding in ("utf-8", "utf-16", "utf-16-be", "utf-16-le", "latin-1", "ascii"):
-		yield check, encoding
+		check(encoding)
 
 
 def test_xmlheader():
@@ -158,20 +159,45 @@ def test_xmlheader():
 
 
 def test_struts_html():
-	assert b'prefix="xyzzx"' in struts_html.taglib().bytes(prefixdefault=u"xyzzx")
+	assert b'prefix="xyzzx"' in struts_html.taglib().bytes(prefixdefault="xyzzx")
 
 
 def test_publish_forcexmlns():
 	e = html.html()
-	s = e.bytes(prefixes={html: u"h", specials: u"s"}, showxmlns=[specials])
-	assert b'xmlns:s="{}"'.format(specials.xmlns) in s
+	s = e.string(prefixes={html: "h", specials: "s"}, showxmlns=[specials])
+	assert 'xmlns:s="{}"'.format(specials.xmlns) in s
 
 
 def test_comment_in_attr():
-	node = html.div(class_=xsc.Comment(u"gurk"))
+	node = html.div(class_=xsc.Comment("gurk"))
 	assert node.bytes() == b"""<div class=""></div>"""
 
 
 def test_doctype_in_attr():
 	node = html.div(class_=html.DocTypeXHTML11())
 	assert node.bytes() == b"""<div class=""></div>"""
+
+
+def test_attribute_order():
+	node = html.div(xml.Attrs(lang="de"), id="id42", align="right", class_="foo")
+	assert node.bytes() == b"""<div xml:lang="de" align="right" class="foo" id="id42"></div>"""
+
+
+def test_allowschemerelurls():
+	node = html.a(href="http://www.example.org/index.html")
+	assert node.bytes() == b'<a href="http://www.example.org/index.html"></a>'
+	assert node.bytes(base="http://www.example.org") == b'<a href="index.html"></a>'
+	assert node.bytes(base="http://www.example.com") == b'<a href="http://www.example.org/index.html"></a>'
+	assert node.bytes(base="http://www.example.com", allowschemerelurls=True) == b'<a href="//www.example.org/index.html"></a>'
+
+	node = specials.url("http://www.example.org/index.html")
+	assert node.bytes() == b'http://www.example.org/index.html'
+	assert node.bytes(base="http://www.example.org") == b'index.html'
+	assert node.bytes(base="http://www.example.com") == b'http://www.example.org/index.html'
+	assert node.bytes(base="http://www.example.com", allowschemerelurls=True) == b'//www.example.org/index.html'
+
+	node = html.span(style="background: url(http://www.example.org/index.html)")
+	assert node.bytes() == b'<span style="background: url(http://www.example.org/index.html)"></span>'
+	assert node.bytes(base="http://www.example.org") == b'<span style="background: url(index.html)"></span>'
+	assert node.bytes(base="http://www.example.com") == b'<span style="background: url(http://www.example.org/index.html)"></span>'
+	assert node.bytes(base="http://www.example.com", allowschemerelurls=True) == b'<span style="background: url(//www.example.org/index.html)"></span>'
